Wraps a data matrix as a graph input node. The matrix can be dense or sparse (dgCMatrix), or a file path to a .spz file for streaming.
Examples
data(aml)
inp <- factor_input(aml, name = "aml")
inp
#> fn_node: input (aml)
Wraps a data matrix as a graph input node. The matrix can be dense or sparse (dgCMatrix), or a file path to a .spz file for streaming.
data(aml)
inp <- factor_input(aml, name = "aml")
inp
#> fn_node: input (aml)