Produces a multi-panel plot of loss, classifier metrics, and factor norms over training iterations.
Usage
# S3 method for class 'training_logger'
plot(x, ...)Produces a multi-panel plot of loss, classifier metrics, and factor norms over training iterations.
# S3 method for class 'training_logger'
plot(x, ...)