Sequentially reads and decodes each chunk, applies fn, and
collects results.
Examples
if (FALSE) { # \dontrun{
# Compute column sums per chunk
st_map_chunks("data.spz", function(chunk, s, e) Matrix::colSums(chunk))
} # }
Sequentially reads and decodes each chunk, applies fn, and
collects results.
if (FALSE) { # \dontrun{
# Compute column sums per chunk
st_map_chunks("data.spz", function(chunk, s, e) Matrix::colSums(chunk))
} # }