Description Usage Arguments Value Examples
Prints 'Hello, world!'.
1 | timesTwo(x)
|
x |
An numberic value indicating if the development or release version number should be returned, default is release. |
A package_version object with either the release
or development version.
1 | timesTwo(x = 20)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.